# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from evrim import Evrim, AsyncEvrim
from tests.utils import assert_matches_type
from evrim.types.profiles import LatestRetrieveResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLatest:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: Evrim) -> None:
        latest = client.profiles.latest.retrieve(
            profile_id="321669910225",
        )
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    def test_method_retrieve_with_all_params(self, client: Evrim) -> None:
        latest = client.profiles.latest.retrieve(
            profile_id="321669910225",
            limit=0,
            offset=0,
        )
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Evrim) -> None:
        response = client.profiles.latest.with_raw_response.retrieve(
            profile_id="321669910225",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        latest = response.parse()
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Evrim) -> None:
        with client.profiles.latest.with_streaming_response.retrieve(
            profile_id="321669910225",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            latest = response.parse()
            assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Evrim) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.profiles.latest.with_raw_response.retrieve(
                profile_id="",
            )


class TestAsyncLatest:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncEvrim) -> None:
        latest = await async_client.profiles.latest.retrieve(
            profile_id="321669910225",
        )
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    async def test_method_retrieve_with_all_params(self, async_client: AsyncEvrim) -> None:
        latest = await async_client.profiles.latest.retrieve(
            profile_id="321669910225",
            limit=0,
            offset=0,
        )
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncEvrim) -> None:
        response = await async_client.profiles.latest.with_raw_response.retrieve(
            profile_id="321669910225",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        latest = await response.parse()
        assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncEvrim) -> None:
        async with async_client.profiles.latest.with_streaming_response.retrieve(
            profile_id="321669910225",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            latest = await response.parse()
            assert_matches_type(LatestRetrieveResponse, latest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncEvrim) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.profiles.latest.with_raw_response.retrieve(
                profile_id="",
            )
